#**************************************************************************
#    copyright            : (C) 2005 by Michael Zimmermann
#    email                : webmaster@incunabulum.de
# ***************************************************************************/

#***************************************************************************
#                                                                         *
#    This program is free software; you can redistribute it and/or modify  *
#    it under the terms of version 2 of the GNU General Public License as  *
#    published by the Free Software Foundation;                            *
#                                                                          *
# **************************************************************************/
 
 
import logging
from qt import QString
 
class ObjectVisualization(object):
    """
    Class responsible for the visualization of the objects information
    """
    
    def __analyzeObject(self, obj):
        """
        Analyzes the object and returns two lists containing dictionaries. Each
        dictionary contains information for one attribute (keys: name, value, doc)
        or method (keys: name, doc)
        """
        all = dir(obj)        
        methods = []
        attributes = []
        
        for i in all:
            attr = getattr(obj, i)
            doc = ''
            if attr.__doc__:
                doc = attr.__doc__.replace('\n', '<br>')
            
            if callable(attr):
                methods.append({'name': i, 'doc': doc})
            else:
                attributes.append({'name': i, 'value': attr, 'doc': doc})


        attributes.sort()
        methods.sort()
        return attributes, methods
        
    
    def getVisualization(self, id, obj):
        """
        Returns a QString object with the html code for the object visualization
        """
        attributes, methods = self.__analyzeObject(obj)
        txt = QString()

        txt.append('<h1>Object Information</h1>')
        txt.append('<b>id:</b> %s<br> ' % id)
        txt.append('<b>class:</b> %s<br>' % obj.__class__.__name__)
        txt.append('<b>module:</b> %s<br>' % obj.__class__.__module__)

        if hasattr(obj, '__Broken_Persistent__'):
            txt.append('''<font color="red"><h2>Warning</h2>
                                   <b><u>This object is broken</u></b>!<br>
                                   Broken objects are placeholders for objects
                                   that can no longer be created because their
                                   class has gone away.<br>
                                   Please add the relevant path to your python path.
                                   This can be done with the configure button above<br></font>''')
            
        txt.append('<h2>Base Classes</h2>')
        bases = []
        spacer = ''
        try:
            bases = obj.mro()
        except:
            bases = obj.__class__.__bases__
        for i in bases:
            txt.append("%s%s.%s<br>" % (spacer, i.__module__, i.__name__))
            spacer = spacer + '&nbsp &nbsp  '

        txt.append('<h2>Attributes</h2>')
        for i in attributes:
            txt.append('''<b>%s:</b> %s<br>
                       <font color="gray" size="-1">%s</font><br><br>''' % (i['name'], i['value'], i['doc']))
        
        txt.append('<h2>Methods</h2>')
        for i in methods:
            txt.append('<b>%s:</b><br> %s<br><br>' % (i['name'], i['doc']))
        
        return txt