#**************************************************************************
#    copyright            : (C) 2005 by Michael Zimmermann
#    email                : webmaster@incunabulum.de
# ***************************************************************************/

#***************************************************************************
#                                                                         *
#    This program is free software; you can redistribute it and/or modify  *
#    it under the terms of version 2 of the GNU General Public License as  *
#    published by the Free Software Foundation;                            *
#                                                                          *
# **************************************************************************/
  
import logging
import sys



from qt import *
from ZODB import DB, FileStorage
from pathconfigbase import PathConfigBase

class PathConfig(PathConfigBase):
    """
    PathConfig widget used to configure the additional (custom) python path
    The new path configuration can be accessed via getPath() and returns a list
    of paths
    """
    
    def __init__(self, paths):
        """
        Default constructor. Takes a list of strings with the paths already
        configured
        """
        PathConfigBase.__init__(self)
        self.__logger = logging.getLogger('PathWindow')        
        self.__logger.debug('PathWindow constructor called')
        self.__modified = False
        

        for item in paths:
            self.pathsList.insertItem(item)
        
    def getPath(self):
        """
        Returns the entered paths as list of strings
        """
        path = []
        item = self.pathsList.firstItem()
        if not item:
            return path
            path.append(str(item.text()))
        while item.next():
            item = item.next()
            path.append(str(item.text()))
        return path

    def dlgOk(self):
        """
        Slot called if ok pressed
        """
        self.__modified = True
        self.close()
    
    def dlgCancel(self):
        """
        Slot called if cancel pressed
        """
        res = QMessageBox.Yes
        if self.__modified:
            res = QMessageBox.question(self, "Discard Changes?",
                                             "There are unsaved changes. Discard?",
                                             QMessageBox.Yes,
                                             QMessageBox.No)
        if res == QMessageBox.Yes:
            self.__modified = False
            self.close()
        
    
    def pathAdd(self):
        """
        Slot called to add another python path
        """
        self.__logger.debug('Add path called')
        path = QFileDialog.getExistingDirectory("", self, "DirectoryDialog",
                                                "Select path to add", True)
        if path:
            if self.pathsList.findItem(path, Qt.ExactMatch):
                # FIXME: ExactMatch is to strict!
                QMessageBox.information(self, "Duplicate path",
                                    "This path is already added to the path list!", 0)
                return
            self.__modified = True
            
            self.pathsList.insertItem(path[0:-1])
                
    def pathRemove(self):
        """
        Slot called to remove selected python path
        """
        selected = self.pathsList.selectedItem()
        if selected:
            self.pathsList.takeItem(selected)
